#
# spec file for package perf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perf
%define version %(rpm -q --qf '%{VERSION}' kernel-source)
Version:        %{version}
Release:        50.1
Summary:        Performance Monitoring Tools for Linux
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
Url:            https://perf.wiki.kernel.org/
BuildRequires:  asciidoc
BuildRequires:  audit-devel
BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gtk2-devel
BuildRequires:  kernel-source >= 2.6.31
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  xz-devel
%ifarch aarch64 ia64 x86_64 ppc64 ppc64le ppc %sparc
BuildRequires:  libnuma-devel
%endif
%ifarch s390x s390
%define         _perf_unwind NO_LIBUNWIND=1
%else
%define         _perf_unwind %{nil}
BuildRequires:  libunwind-devel
%endif
BuildRequires:  newt-devel
BuildRequires:  openssl-devel
BuildRequires:  xmlto
BuildRequires:  zlib-devel
# dl_open requirement so not autodetected
%ifarch ppc64 ppc64le
Requires:       libebl
%endif
%{perl_requires}
%{?libperl_requires}
Patch1:         perf-probe-fix-to-free-temporal-dwarf_frame.patch
Patch2:         perf-probe-fix-to-free-temporal-dwarf_frame-correctly.patch
Patch3:         perf-probe-search-both-eh_frame-and-debug_frame-sections-for-probe-location.patch
Patch4:         perf-symbols-refactor-vmlinux_path__init-to-ease-path-additions.patch
Patch5:         perf-symbols-add-the-path-to-vmlinux.debug.patch
Patch6:         perf-powerpc-0001-Fix-kprobe-and-kretprobe-handling-with-.patch
Patch7:         perf-powerpc-0002-symbols-Fix-kallsyms-perf-test-on-ppc64le.patch
Patch8:         perf-powerpc-0003-probe-Add-function-to-post-process-kernel-trace.patch
Patch9:         perf-powerpc-0004-probe-ppc64le-Fix-probe-location-when-using-DWA.patch
Patch10:        perf-powerpc-0005-ppc64le-Fix-build-failure-when-libelf-is-not-pr.patch
Patch11:        perf-powerpc-0006-tools-Add-missing-struct-definition-in-probe_ev.patch
Patch12:        perf-variable-0001-probe-Fix-to-show-correct-error-message-for-var.patch
Patch13:        perf-variable-0002-probe-Add-helper-function-to-check-if-probe-wit.patch
Patch14:        perf-variable-0003-uprobe-Skip-prologue-if-program-compiled-withou.patch
Patch15:        perf-scripting-python-add-ppc64le-to-audit-uname-list.patch
Patch16:        perf-probe-fix-offline-module-name-missmatch-issue.patch
Patch17:        perf-probe-fix-module-probe-issue-if-no-dwarf-support.patch
Patch18:        perf-pmu-events-support-additional-power8-pvr-in-mapfile.patch
Patch19:        perf-vendor-events-add-power9-pmu-events.patch
Patch20:        perf-vendor-events-add-power9-pvrs-to-mapfile.patch
Patch21:        perf-vendor-events-powerpc-remove-suffix-in-mapfile.patch
Patch22:        perf-vendor-events-powerpc-update-power9-events.patch
Patch23:        perf-vendor-events-powerpc-remove-duplicate-events.patch
Patch24:        tools-lib-traceevent-add-operation-within-arg_num_eval.patch
Patch25:        perf-pmu-only-print-using-cpuid-message-once.patch
Patch26:        perf-pmu-extract-function-to-get-json-alias-map.patch
Patch27:        perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch

Requires:       kernel >= 2.6.31
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a userspace tool 'perf', which monitors performance for
either unmodified binaries or the entire system. It requires a Linux kernel
which includes the Performance Counters for Linux (PCL) subsystem (>= 2.6.31).
This subsystem utilizes the Performance Monitoring Unit (PMU) / hardware
counters of the underlying cpu architecture (if supported).

%prep
# copy necessary files from kernel-source since we need to modify them
(cd /usr/src/linux ; tar -cf - COPYING CREDITS README tools include scripts Kbuild Makefile arch/*/{include,lib,Makefile} lib) | tar -xf - 
chmod +x tools/perf/util/generate-cmdlist.sh
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1

%build
cd tools/perf
export WERROR=0
# PASS rpm optflags as EXTRA_FLAGS,  passing as CFLAGS overrides and breaks build
make %{?_smp_mflags} -f Makefile.perf EXTRA_CFLAGS="%{optflags}" ASCIIDOC8=1 prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core all doc %{_perf_unwind} tipdir=share/doc/packages/perf

%install
cd tools/perf
export WERROR=0
make -f Makefile.perf V=1 EXTRA_CFLAGS="%{optflags}" prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core DESTDIR=%{buildroot} install install-doc %{_perf_unwind} tipdir=share/doc/packages/perf

%files
%defattr(-, root, root)
%doc COPYING CREDITS README tools/perf/design.txt
%{_bindir}/perf
%{_bindir}/trace
%{_libdir}/libperf-gtk.so
%ifnarch armv7l
%dir %{_libdir}/traceevent
%dir %{_libdir}/traceevent/plugins
%{_libdir}/traceevent/plugins/plugin_*.so
%endif
%attr(0644, -, -) %{_sysconfdir}/bash_completion.d/perf
%{_libexecdir}/%{name}-core
%{_datarootdir}/%{name}-core
%{_mandir}/man1/perf*

%changelog
* Wed Aug  1 2018 tonyj@suse.com
- PMU events are not listed because pvr code is missing for POWER9 (bsc#1075525 )
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-pmu-only-print-using-cpuid-message-once.patch
  New patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
* Sat Jan 27 2018 tonyj@suse.com
- Correctly handle '~' operation in traceevent print flags (bsc#1074087)
  New patch: tools-lib-traceevent-add-operation-within-arg_num_eval.patch
* Thu Jan 18 2018 tonyj@suse.com
- perf probe on offline module is not working (bsc#1041074)
  New patch: perf-probe-fix-offline-module-name-missmatch-issue.patch
  New patch: perf-probe-fix-module-probe-issue-if-no-dwarf-support.patch
* Thu Jan 18 2018 tonyj@suse.com
- Add necessary power pvr support (bsc#1075525)
  New patch: perf-pmu-events-support-additional-power8-pvr-in-mapfile.patch
  New patch: perf-vendor-events-add-power9-pmu-events.patch
  New patch: perf-vendor-events-add-power9-pvrs-to-mapfile.patch
  New patch: perf-vendor-events-powerpc-remove-suffix-in-mapfile.patch
  New patch: perf-vendor-events-powerpc-update-power9-events.patch
  New patch: perf-vendor-events-powerpc-remove-duplicate-events.patch
* Wed Dec  6 2017 tonyj@suse.com
- Add perf scripting support for ppc64le (bsc#1056756)
  New patch: perf-scripting-python-add-ppc64le-to-audit-uname-list.patch
* Fri Jun 23 2017 msuchanek@suse.com
- perf probe: Fails to record samples when probed with function parameter (bsc#1040940)
  perf-powerpc-0001-Fix-kprobe-and-kretprobe-handling-with-.patch
  perf-powerpc-0002-symbols-Fix-kallsyms-perf-test-on-ppc64le.patch
  perf-powerpc-0003-probe-Add-function-to-post-process-kernel-trace.patch
  perf-powerpc-0004-probe-ppc64le-Fix-probe-location-when-using-DWA.patch
  perf-powerpc-0005-ppc64le-Fix-build-failure-when-libelf-is-not-pr.patch
  perf-powerpc-0006-tools-Add-missing-struct-definition-in-probe_ev.patch
- perf uprobe: garbage value recorded when target program compiled without optimization (bsc#1041073)
  perf-variable-0001-probe-Fix-to-show-correct-error-message-for-var.patch
  perf-variable-0002-probe-Add-helper-function-to-check-if-probe-wit.patch
  perf-variable-0003-uprobe-Skip-prologue-if-program-compiled-withou.patch
* Thu Jun 15 2017 tonyj@suse.com
- Correct auto search path to debug kernel (bsc#1044591)
  new patch: perf-symbols-refactor-vmlinux_path__init-to-ease-path-additions.patch
  new patch: perf-symbols-add-the-path-to-vmlinux.debug.patch
- Add ppc64 requires on libebl (bsc#1040770) which is manually loaded by perf
  probe/etc (dl_open)
* Wed Apr 26 2017 tonyj@suse.com
- Force package rebuild for SP3 picking up new kernel-sources (bsc#1032838)
* Tue Jul 12 2016 tonyj@suse.com
- search both .eh_frame and .debug_frame sections for probe location (bsc#986927)
  Add patch: perf-probe-fix-to-free-temporal-dwarf_frame.patch
  Add patch: perf-probe-fix-to-free-temporal-dwarf_frame-correctly.patch
  Add patch: perf-probe-search-both-eh_frame-and-debug_frame-sections-for-probe-location.patch
* Mon Jun 13 2016 tonyj@suse.com
- Update SP2 package to build from SP2 v4.4 kernel-source (use latest spec
  from Factory to pickup recent build fixes for post SP1 kernel)
- Drop patch: perf-probe-ppc64le-prefer-symbol-table-lookup-over-dwarf.patch (upstream)
- Drop perf-tips (%%doc), not in v4.4 kernel
* Fri Aug 14 2015 tonyj@suse.com
- Branch package for SP1 to pick up kernel-source changes
  (FATE#318982, FATE#318983, FATE#318984)
- Perf probe: prefer symbol table lookup over DWARF for ppc64le
  (bnc#936752)
  New patch: perf-probe-ppc64le-prefer-symbol-table-lookup-over-dwarf.patch
* Fri Jun 27 2014 tonyj@suse.com
- Build for s390[x] without libunwind (bnc#882855)
* Thu Feb 20 2014 ro@suse.de
- add excludearch for s390/s390x: have no libunwind there
* Wed Dec  4 2013 tonyj@suse.com
- Drop patch perl-5.18-nowarn.patch (mainline)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Wed Aug 21 2013 tonyj@suse.com
- Resolve build errors
- Drop patch perf-tests-ppc64-fix-compile-errors.patch (mainline)
- Refresh patch perl-5.18-nowarn.patch
* Wed Jul 10 2013 tonyj@suse.com
- Add patch 'perf-tests-ppc64-fix-compile-errors.patch' to resolve
  openSUSE:Factory:PowerPC testsuite build errors
* Tue Jul  9 2013 tonyj@suse.com
- Add audit-devel, gtk2-devel and libunwind-devel to support optional
  functionality.
- Add 'perl-5.18-nowarn.patch' to squelch build errors from perl.h
- Add perl_requires
- Fix --version output (copy submakefiles from kernel-source)
- Pass SUSE rpm optflags into make as EXTRA_CFLAGS not CFLAGS
- Stop building with V=1, make output easier to parse
* Tue Dec 25 2012 tonyj@suse.com
- Add /etc/bash_completion.d/perf to %%files (fix build error)
* Wed May 16 2012 toganm@opensuse.org
- Fix build for factory
  * added flex and bison to buildrequires
* Thu May  5 2011 idoenmez@novell.com
- Also copy arch/lib to fix compilation on x86-64
- Correctly depend on libdw-devel to fix dwarf support
- Add newt-devel dependency to enable text user interface
- Re-enable as-needed support since it works now
* Tue Mar  9 2010 tonyj@novell.com
- 2.6.33 changes
  add perf-bench, perf-buildid-list, perf-diff, perf-kmem, perf-probe and
  perf-trace-perl
  [Still pending, update of libdwarf to version > 20081231]
* Thu Nov  5 2009 tonyj@novell.com
- 2.6.32 changes
  add perf-sched, perf-timechart and perf-trace man pages
* Wed Aug 26 2009 aj@suse.de
- Remove libbfd.patch since it does not apply and use
  SUSE_ASNEEDED=0 instead.
- Set flag for asciidoc version 8.
* Sun Aug  2 2009 tonyj@suse.de
- Initial checkin of Performance Counters for Linux (PCL) userspace.
  This builds tools/perf out of kernel-source package and requires
  kernel >= 2.6.31
